/* This is the default Startup script.  Any changes made to this file will be overwritten.  
   If you wish to use a different startup script, change the setting in the Session startup
   sequence */

variable int SessionNumber

function main()
{
  call SetSessionName

  alias binds bind -list
  alias GlobalBinds GlobalBind -list

  call SetBinds

}

function SetBinds()
{
/* UI-related binds */
  bind memoryindicator CTRL+ALT+M hudgroup -toggle "memory indicator"
  bind fpsindicator CTRL+ALT+F hudgroup -toggle "fps indicator"

/* window size binds */
  alias fullscreen "WindowSize -fullscreen;WindowPosition -viewable \${Display.DesktopX},\${Display.DesktopY};fullscreenmouse"
  alias normal "normalsize;normalposition;normalmouse"
  alias tiny "tinysize;tinyposition;tinymouse"
  alias pipforeground "pipforegroundsize;pipforegroundposition;pipforegroundmouse"

  switch "${Game.Name}"
  {
  case EverQuest
    call EQSession
    break
  case Guild Wars
    alias fullscreen "WindowSize -rescale -fullscreen;WindowPosition -stealth -viewable \${Display.DesktopX},\${Display.DesktopY};fullscreenmouse"
    break

/* This is how to add special stuff for other games
   ----------------------------------------------------------- */
  case Other Game
    call NormalSession
    break
/* ----------------------------------------------------------- */

  default
    call NormalSession
    break
  }
}




function SetSessionName()
{
  declare Count int local 1
  do
  {
    if !${Session[is${Count}]}
    {
      Uplink Name is${Count}
      WaitFor "accepted" "rejected" 100
      if ${WaitFor}==2
        continue
      SessionNumber:Set[${Count}]
      if ${Count}<10
      {
		WindowText is${Count} (CTRL+ALT+${Count})
	  
		GlobalBind is${Count}_key CTRL+ALT+${Count} "WindowVisibility foreground"
      }
      else
      {
        WindowText is${Count} (No Hotkey)
      }
      
      break
    }
  }
  while "${Count:Inc}<100"
}

atom(globalkeep) EQOnWindowPos(bool Stealth)
{
  if ${Display.Windowed} && ${Display.ViewableWidth}
  {
   /*  echo set scale... */
    Mouse.ScaleX:Set[${Display.Width}/${Display.ViewableWidth}]
    Mouse.ScaleY:Set[${Display.Height}/${Display.ViewableHeight}]
  }
  else
  {
    Mouse.ScaleX:Set[1.0]
    Mouse.ScaleY:Set[1.0]
  }
}

function EQSession()
{
/* customize this part for EverQuest 1 */

  /* EQ1 is unstable with multiple CPUs. This will rotate the affinity between two cores */
  if ${SessionNumber}%2==1
     proc 1 only
  else
     proc 2 only
  
  /* Set up our mouse transformation handler for when people resize the window, since EQ1 does not
     scale the display on purpose. */
  Event[On Window Position]:AttachAtom[EQOnWindowPos]

  alias normalsize WindowSize -Reset
  alias tinysize WindowScale 20
  alias pipforegroundsize WindowSize -Reset
  alias normalposition WindowPos -viewable ${Math.Calc[${Display.DesktopX}+10].Int},${Math.Calc[${Display.DesktopY}+10].Int}
  alias tinyposition WindowPos ${Math.Calc[${Display.DesktopX}+10].Int},${Math.Calc[${Display.DesktopY}+10].Int}
  alias pipforegroundposition WindowPos -viewable ${Display.DesktopX},${Display.DesktopY}
  alias fullscreenmouse
  alias normalmouse
  alias tinymouse
  alias pipforegroundmouse

  bind fullscreenkey SHIFT+ALT+f fullscreen
  bind normalkey SHIFT+ALT+n normal
  bind tinykey SHIFT+ALT+t tiny
  bind next CTRL+ALT+x "uplink focus -next"
  bind previous CTRL+ALT+z "uplink focus -previous"
}

function NormalSession()
{
/* customize this part for other games */
  alias normalsize WindowSize -viewable 1024x768
  alias tinysize WindowSize -viewable 256x192
  alias pipforegroundsize WindowSize -rescale -viewable ${Display.Width}x${Display.Height}
  alias normalposition WindowPos -viewable \${Display.DesktopX},\${Display.DesktopY}
  alias tinyposition WindowPos \${Math.Calc[\${Display.DesktopX}+10].Int},\${Math.Calc[\${Display.DesktopY}+10].Int}
  alias pipforegroundposition WindowPos -viewable \${Display.DesktopX},\${Display.DesktopY}
  alias fullscreenmouse
  alias normalmouse
  alias pipforegroundmouse
  alias tinymouse

  bind fullscreenkey SHIFT+ALT+f fullscreen
  bind normalkey SHIFT+ALT+n normal
  bind tinykey SHIFT+ALT+t tiny
  bind next CTRL+ALT+x "uplink focus -next"
  bind previous CTRL+ALT+z "uplink focus -previous"
}